import os

from bs4 import BeautifulSoup

from vabot.config import BaseConfig as cfg

class VabotDebug(object):    
    def search_with_bing(self):
        html = open(os.path.join(cfg.BASE_DIR, "response.html"), "r", encoding="UTF-8")
        

        soup: BeautifulSoup = BeautifulSoup(html, "html.parser")
        try:
            contents = soup.find("div", attrs={"id": "b_wpt_data"}).get("data-sydctx")
            return contents
        except:
            contents = "Data Tidak Ditemukan"


# BASE VABOT

import httpx
import os

from typing import Optional, Any
from fake_useragent import UserAgent
from bs4 import BeautifulSoup
from rich import print

from vabot.config import BaseConfig as cfg

ua = UserAgent()

class BaseChatBotAI(object):
    def search_with_bing(self, query: str):
        url: str = "https://www.bing.com/"
        params: dict[str, Any] = {
            "q": query,
            "form": "QBLH",
            "sp": -1,
            "ghc": 1,
            "lq": 0,
            "pq": query,
            "sc": "11-14",
            "qs": "n",
            "sk": "",
            "cvid": "990C10F11D944BCDA403229F51D97078",
            "ghsh": 0,
            "ghacc": 0,
            "ghpl": "",
        }
        headers: dict[str, Any] = {
            "User-Agent": ua.edge
        }
        search_url = url + "search"
        response = httpx.get(search_url, params=params, headers=headers)
        print("Process URL: {}".format(response.url))

        # get response
        f = open(os.path.join(cfg.BASE_DIR, "response.html"), "w+", encoding="UTF-8")
        f.write(response.text)
        f.close()

        soup: BeautifulSoup = BeautifulSoup(response.text, "html.parser")

        try:
            contents = soup.find("div", attrs={"id": "b_wpt_data"}).get("data-sydctx")
            return contents
        except:
            contents = "Data Tidak Ditemukan"
            return contents


# instance for bot
import telebot
from telebot.async_telebot import AsyncTeleBot

from vabot.config import BaseConfig as cfg
from vabot.chatbot import ChatBotAI

bot = AsyncTeleBot(token=cfg.TELEGRAM_API_KEY) # You can set parse_mode by default. HTML or MARKDOWN

@bot.message_handler(commands=['help', 'start'])
async def send_welcome(message):
    await bot.reply_to(message, """\
Hi there, I am EchoBot.
I am here to echo your kind words back to you. Just say anything nice and I'll say the exact same thing to you!\
""")


# command for bot
@bot.message_handler(commands=['search'])
async def search_command(message):
    search = ChatBotAI(api_key=cfg.API_KEY, organization_id=cfg.ORGANIZATION_ID)
    query = message.text.replace("search", "")
    await bot.reply_to(message, search.search_with_bing(query=query))


import os
from pathlib import Path
from os.path import join
from dotenv import load_dotenv

load_dotenv(join(Path(__file__).resolve().parent.parent.parent, ".env"))

class BaseConfig(object):
    API_KEY= os.environ.get("API_KEY")
    BASE_DIR = Path(__file__).resolve().parent.parent.parent
    ORGANIZATION_ID= os.environ.get("ORGANIZATION_ID")
    TELEGRAM_API_KEY= os.environ.get("TELEGRAM_BOT_API_KEY")

    # SSL Configuration
    CERT_PEM = join(BASE_DIR, "cert.pem")
    KEY_PEM  = join(BASE_DIR, "key.pem")





from openai import OpenAI
from typing import Optional

import httpx
import os

from typing import Optional, Any
from httpx import Client
from fake_useragent import UserAgent
from bs4 import BeautifulSoup
from rich import print

from vabot.config import BaseConfig as cfg
from vabot.base import BaseChatBotAI

class ChatBotAI(BaseChatBotAI):
    def __init__(
        self, api_key: Optional[str] = None, organization_id: Optional[str] = None) -> None:
        self.api_key: Optional[str] = api_key
        self.engine: str = "text-davinci-003"
        self.model = ["gpt-3.5-turbo"]
        self.oganization_id = organization_id
        self.search_engine: list[str] = ["google", "bing"]
        self.client: Client = Client()
        self.openai: OpenAI = OpenAI(api_key=self.api_key, organization=self.oganization_id)